@@ -20,7 +20,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #ifdef HAVE_MEMORY_H
@@ -34,21 +34,22 @@
 
 #include <libxfce4util/libxfce4util.h>
 
-#include <thunar/thunar-application.h>
-#include <thunar/thunar-chooser-dialog.h>
-#include <thunar/thunar-dbus-service.h>
-#include <thunar/thunar-file.h>
-#include <thunar/thunar-gdk-extensions.h>
-#include <thunar/thunar-preferences-dialog.h>
-#include <thunar/thunar-private.h>
-#include <thunar/thunar-properties-dialog.h>
-#include <thunar/thunar-util.h>
+#include "thunar/thunar-application.h"
+#include "thunar/thunar-preferences.h"
+#include "thunar/thunar-chooser-dialog.h"
+#include "thunar/thunar-dbus-service.h"
+#include "thunar/thunar-file.h"
+#include "thunar/thunar-gdk-extensions.h"
+#include "thunar/thunar-preferences-dialog.h"
+#include "thunar/thunar-private.h"
+#include "thunar/thunar-properties-dialog.h"
+#include "thunar/thunar-util.h"
 
 
 
 /* include generate dbus infos */
-#include <thunar/thunar-dbus-freedesktop-interfaces.h>
-#include <thunar/thunar-dbus-service-infos.h>
+#include "thunar/thunar-dbus-freedesktop-interfaces.h"
+#include "thunar/thunar-dbus-service-infos.h"
 
 
 
@@ -79,13 +80,6 @@ static gboolean thunar_dbus_service_transfer_files              (ThunarDBusTrans
                                                                  GError                **error);
 static void     thunar_dbus_service_trash_bin_changed           (ThunarDBusService      *dbus_service,
                                                                  ThunarFile             *trash_bin);
-static gboolean thunar_dbus_service_display_chooser_dialog      (ThunarDBusFileManager  *object,
-                                                                 GDBusMethodInvocation  *invocation,
-                                                                 const gchar            *uri,
-                                                                 gboolean                open,
-                                                                 const gchar            *display,
-                                                                 const gchar            *startup_id,
-                                                                 ThunarDBusService      *dbus_service);
 static gboolean thunar_dbus_service_display_app_chooser_dialog  (ThunarDBusFileManager  *object,
                                                                  GDBusMethodInvocation  *invocation,
                                                                  const gchar            *uri,
@@ -312,7 +306,6 @@ thunar_dbus_service_init (ThunarDBusService *dbus_service)
   dbus_service->file_manager_fdo  = thunar_org_freedesktop_file_manager1_skeleton_new ();
 
   connect_signals_multiple (dbus_service->file_manager, dbus_service,
-                            "handle-display-chooser-dialog", thunar_dbus_service_display_chooser_dialog,
                             "handle-display-application-chooser-dialog", thunar_dbus_service_display_app_chooser_dialog,
                             "handle-display-folder", thunar_dbus_service_display_folder,
                             "handle-display-folder-and-select", thunar_dbus_service_display_folder_and_select,
@@ -441,45 +434,6 @@ thunar_dbus_service_trash_bin_changed (ThunarDBusService *dbus_service,
 
 
 
-/**
- * TODO: Method to be removed after thunar 4.18 got released (dbus call is marked as deprecated). Use thunar_dbus_service_display_app_chooser_dialog instead.
- */
-static gboolean
-thunar_dbus_service_display_chooser_dialog (ThunarDBusFileManager  *object,
-                                            GDBusMethodInvocation  *invocation,
-                                            const gchar            *uri,
-                                            gboolean                open,
-                                            const gchar            *display,
-                                            const gchar            *startup_id,
-                                            ThunarDBusService      *dbus_service)
-{
-  ThunarFile *file;
-  GdkScreen  *screen;
-  GError     *error = NULL;
-
-  /* parse uri and display parameters */
-  if (!thunar_dbus_service_parse_uri_and_display (dbus_service, uri, display, &file, &screen, &error))
-    goto out;
-
-  /* popup the chooser dialog */
-  /* TODO use the startup id! */
-  thunar_show_chooser_dialog (screen, file, open, FALSE);
-
-  /* cleanup */
-  g_object_unref (G_OBJECT (screen));
-  g_object_unref (G_OBJECT (file));
-
-out:
-  if (error)
-    g_dbus_method_invocation_take_error (invocation, error);
-  else
-    thunar_dbus_file_manager_complete_display_chooser_dialog (object, invocation);
-
-  return TRUE;
-}
-
-
-
 static gboolean
 thunar_dbus_service_display_app_chooser_dialog (ThunarDBusFileManager  *object,
                                                 GDBusMethodInvocation  *invocation,
@@ -510,7 +464,7 @@ out:
   if (error)
     g_dbus_method_invocation_take_error (invocation, error);
   else
-    thunar_dbus_file_manager_complete_display_chooser_dialog (object, invocation);
+    thunar_dbus_file_manager_complete_display_application_chooser_dialog (object, invocation);
 
   return TRUE;
 }
@@ -728,7 +682,7 @@ thunar_dbus_service_execute (ThunarDBusFileManager  *object,
 
       /* try to launch the file on the given screen */
       working_dir = g_file_new_for_commandline_arg (working_directory);
-      thunar_file_execute (file, working_dir, screen, file_list, startup_id, &error);
+      thunar_file_execute (file, working_dir, screen, FALSE, file_list, startup_id, &error);
       g_object_unref (working_dir);
 
       /* cleanup */
@@ -871,12 +825,15 @@ thunar_dbus_service_move_to_trash (ThunarDBusTrash        *object,
                                    ThunarDBusService      *dbus_service)
 {
   ThunarApplication *application;
+  ThunarPreferences *preferences;
+  ThunarFile        *thunar_file;
   GFile             *file;
   GdkScreen         *screen;
   GError            *err = NULL;
   GList             *file_list = NULL;
   gchar             *filename;
   guint              n;
+  gboolean           warn;
 
   /* try to open the screen for the display name */
   screen = thunar_gdk_screen_open (display, &err);
@@ -890,9 +847,12 @@ thunar_dbus_service_move_to_trash (ThunarDBusTrash        *object,
           if (G_LIKELY (err == NULL))
             {
               /* determine the path for the filename */
-              /* TODO Not sure this will work as expected */
               file = g_file_new_for_commandline_arg (filename);
-              file_list = thunar_g_list_append_deep (file_list, file);
+              thunar_file = thunar_file_get (file, &err);
+
+              if (thunar_file != NULL)
+                file_list = g_list_append (file_list, thunar_file);
+
               g_object_unref (file);
             }
 
@@ -903,9 +863,14 @@ thunar_dbus_service_move_to_trash (ThunarDBusTrash        *object,
       /* check if we succeed */
       if (G_LIKELY (err == NULL))
         {
+          /* check if the user wants a confirmation before moving to trash */
+          preferences = thunar_preferences_get ();
+          g_object_get (G_OBJECT (preferences), "misc-confirm-move-to-trash", &warn, NULL);
+          g_object_unref (G_OBJECT (preferences));
+          
           /* tell the application to move the specified files to the trash */
           application = thunar_application_get ();
-          thunar_application_trash (application, screen, file_list, THUNAR_OPERATION_LOG_NO_OPERATIONS);
+          thunar_application_unlink_files (application, screen, file_list, FALSE, warn, THUNAR_OPERATION_LOG_NO_OPERATIONS);
           g_object_unref (application);
         }
 
@@ -1506,7 +1471,7 @@ thunar_dbus_service_unlink_files (ThunarDBusFileManager  *object,
         {
           /* tell the application to move the specified files to the trash */
           application = thunar_application_get ();
-          thunar_application_unlink_files (application, screen, file_list, TRUE, TRUE);
+          thunar_application_unlink_files (application, screen, file_list, TRUE, TRUE, THUNAR_OPERATION_LOG_NO_OPERATIONS);
           g_object_unref (application);
         }
 
