@@ -19,12 +19,12 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <libxfce4util/libxfce4util.h>
 
-#include <thunar/thunar-enum-types.h>
+#include "thunar/thunar-enum-types.h"
 
 
 
@@ -33,7 +33,45 @@ static void                thunar_icon_size_from_zoom_level     (const GValue
 static void                thunar_thumbnail_size_from_icon_size (const GValue   *src_value,
                                                                  GValue         *dst_value);
 static ThunarIconSize      thunar_zoom_level_to_icon_size       (ThunarZoomLevel zoom_level);
-static ThunarThumbnailSize thunar_icon_size_to_thumbnail_size   (ThunarIconSize  icon_size);
+
+
+
+gboolean
+transform_enum_value_to_index (GBinding     *binding,
+                               const GValue *src_value,
+                               GValue       *dst_value,
+                               gpointer      user_data)
+{
+  GEnumClass *klass;
+  GType     (*type_func)() = user_data;
+  guint       n;
+
+  klass = g_type_class_ref (type_func ());
+  for (n = 0; n < klass->n_values; ++n)
+    if (klass->values[n].value == g_value_get_enum (src_value))
+      g_value_set_int (dst_value, n);
+  g_type_class_unref (klass);
+
+  return TRUE;
+}
+
+
+
+gboolean
+transform_index_to_enum_value (GBinding     *binding,
+                               const GValue *src_value,
+                               GValue       *dst_value,
+                               gpointer      user_data)
+{
+  GEnumClass *klass;
+  GType     (*type_func)() = user_data;
+
+  klass = g_type_class_ref (type_func ());
+  g_value_set_enum (dst_value, klass->values[g_value_get_int (src_value)].value);
+  g_type_class_unref (klass);
+
+  return TRUE;
+}
 
 
 
@@ -418,6 +456,7 @@ thunar_parallel_copy_mode_get_type (void)
         { THUNAR_PARALLEL_COPY_MODE_ALWAYS,                  "THUNAR_PARALLEL_COPY_MODE_ALWAYS",                  "always",                  },
         { THUNAR_PARALLEL_COPY_MODE_ONLY_LOCAL,              "THUNAR_PARALLEL_COPY_MODE_ONLY_LOCAL",              "only-local",              },
         { THUNAR_PARALLEL_COPY_MODE_ONLY_LOCAL_SAME_DEVICES, "THUNAR_PARALLEL_COPY_MODE_ONLY_LOCAL_SAME_DEVICES", "only-local-same-devices", },
+        { THUNAR_PARALLEL_COPY_MODE_ONLY_LOCAL_IDLE_DEVICE,  "THUNAR_PARALLEL_COPY_MODE_ONLY_LOCAL_IDLE_DEVICE",  "only-local-idle-device",  },
         { THUNAR_PARALLEL_COPY_MODE_NEVER,                   "THUNAR_PARALLEL_COPY_MODE_NEVER",                   "never",                   },
         { 0,                                                 NULL,                                                NULL,                      },
       };
@@ -460,16 +499,39 @@ thunar_zoom_level_to_icon_size (ThunarZoomLevel zoom_level)
 
 
 
-static ThunarThumbnailSize
+gint
+thunar_zoom_level_to_view_margin (ThunarZoomLevel zoom_level)
+{
+  switch (zoom_level)
+    {
+    case THUNAR_ZOOM_LEVEL_25_PERCENT:   return 3;
+    case THUNAR_ZOOM_LEVEL_38_PERCENT:   return 3;
+    case THUNAR_ZOOM_LEVEL_50_PERCENT:   return 3;
+    case THUNAR_ZOOM_LEVEL_75_PERCENT:   return 3;
+    case THUNAR_ZOOM_LEVEL_100_PERCENT:  return 3;
+    case THUNAR_ZOOM_LEVEL_150_PERCENT:  return 5;
+    case THUNAR_ZOOM_LEVEL_200_PERCENT:  return 10;
+    case THUNAR_ZOOM_LEVEL_250_PERCENT:  return 12;
+    case THUNAR_ZOOM_LEVEL_300_PERCENT:  return 15;
+    case THUNAR_ZOOM_LEVEL_400_PERCENT:  return 18;
+    case THUNAR_ZOOM_LEVEL_800_PERCENT:  return 20;
+    case THUNAR_ZOOM_LEVEL_1600_PERCENT: return 40;
+    default:                             return 3;
+    }
+}
+
+
+
+ThunarThumbnailSize
 thunar_icon_size_to_thumbnail_size (ThunarIconSize icon_size)
 {
-  if (icon_size >= THUNAR_ICON_SIZE_1024)
+  if (icon_size > THUNAR_ICON_SIZE_512)
     return THUNAR_THUMBNAIL_SIZE_XX_LARGE;
 
-  if (icon_size >= THUNAR_ICON_SIZE_512)
+  if (icon_size > THUNAR_ICON_SIZE_256)
     return THUNAR_THUMBNAIL_SIZE_X_LARGE;
 
-  if (icon_size >= THUNAR_ICON_SIZE_128)
+  if (icon_size > THUNAR_ICON_SIZE_128)
     return THUNAR_THUMBNAIL_SIZE_LARGE;
 
   return THUNAR_THUMBNAIL_SIZE_NORMAL;
@@ -701,8 +763,8 @@ thunar_image_preview_mode_get_type (void)
     {
       static const GEnumValue values[] =
       {
-        { THUNAR_IMAGE_PREVIEW_MODE_STANDALONE, "THUNAR_IMAGE_PREVIEW_MODE_STANDALONE", N_("Standalone Image Preview") },
-        { THUNAR_IMAGE_PREVIEW_MODE_EMBEDDED,   "THUNAR_IMAGE_PREVIEW_MODE_EMBEDDED",   N_("Embedded Image Preview") },
+        { THUNAR_IMAGE_PREVIEW_MODE_STANDALONE, "THUNAR_IMAGE_PREVIEW_MODE_STANDALONE", N_("Standalone") },
+        { THUNAR_IMAGE_PREVIEW_MODE_EMBEDDED,   "THUNAR_IMAGE_PREVIEW_MODE_EMBEDDED",   N_("Embedded") },
         { 0,                                    NULL,                                   NULL }
       };
 
@@ -712,3 +774,90 @@ thunar_image_preview_mode_get_type (void)
   return type;
 }
 
+GType thunar_folder_item_count_get_type (void)
+{
+  static GType type = G_TYPE_INVALID;
+
+  if (G_UNLIKELY (type == G_TYPE_INVALID))
+    {
+      static const GEnumValue values[] =
+      {
+        { THUNAR_FOLDER_ITEM_COUNT_NEVER,       "THUNAR_FOLDER_ITEM_COUNT_NEVER",       N_("Never") },
+        { THUNAR_FOLDER_ITEM_COUNT_ONLY_LOCAL,  "THUNAR_FOLDER_ITEM_COUNT_ONLY_LOCAL",  N_("Only for local files") },
+        { THUNAR_FOLDER_ITEM_COUNT_ALWAYS,      "THUNAR_FOLDER_ITEM_COUNT_ALWAYS",      N_("Always") },
+        { 0,                                    NULL,                                   NULL }
+      };
+
+      type = g_enum_register_static ("ThunarFolderItemCount", values);
+    }
+
+  return type;
+}
+
+GType thunar_window_title_style_get_type (void)
+{
+  static GType type = G_TYPE_INVALID;
+
+  if (G_UNLIKELY (type == G_TYPE_INVALID))
+    {
+      static const GEnumValue values[] =
+      {
+        { THUNAR_WINDOW_TITLE_STYLE_FOLDER_NAME_WITH_THUNAR_SUFFIX,    "THUNAR_WINDOW_TITLE_STYLE_FOLDER_NAME_WITH_THUNAR_SUFFIX",    "folder-name-with-suffix" },
+        { THUNAR_WINDOW_TITLE_STYLE_FOLDER_NAME_WITHOUT_THUNAR_SUFFIX, "THUNAR_WINDOW_TITLE_STYLE_FOLDER_NAME_WITHOUT_THUNAR_SUFFIX", "folder-name-without-suffix" },
+        { THUNAR_WINDOW_TITLE_STYLE_FULL_PATH_WITH_THUNAR_SUFFIX,      "THUNAR_WINDOW_TITLE_STYLE_FULL_PATH_WITH_THUNAR_SUFFIX",      "full-path-with-suffix" },
+        { THUNAR_WINDOW_TITLE_STYLE_FULL_PATH_WITHOUT_THUNAR_SUFFIX,   "THUNAR_WINDOW_TITLE_STYLE_FULL_PATH_WITHOUT_THUNAR_SUFFIX",   "full-path-without-suffix" },
+        { 0,                                                           NULL,                                                          NULL }
+      };
+
+      type = g_enum_register_static ("ThunarWindowTitleStyle", values);
+    }
+
+  return type;
+}
+
+GType thunar_sidepane_type_get_type (void)
+{
+  static GType type = G_TYPE_INVALID;
+
+  if (G_UNLIKELY (type == G_TYPE_INVALID))
+    {
+      static const GEnumValue values[] =
+      {
+        { THUNAR_SIDEPANE_TYPE_SHORTCUTS,       "THUNAR_SIDEPANE_TYPE_SHORTCUTS",        ("Shurtcuts sidepane") },
+        { THUNAR_SIDEPANE_TYPE_TREE,            "THUNAR_SIDEPANE_TYPE_TREE",             ("Tree sidepane") },
+        { THUNAR_SIDEPANE_TYPE_HIDDEN_SHORTCUTS,"THUNAR_SIDEPANE_TYPE_HIDDEN_SHORTCUTS", ("No sidepane. On toggle, recover to shurtcuts sidepane") },
+        { THUNAR_SIDEPANE_TYPE_HIDDEN_TREE,     "THUNAR_SIDEPANE_TYPE_HIDDEN_TREE",      ("No sidepane. On toggle, recover to tree sidepane") },
+        /* Support for deprecated old types */
+        { THUNAR_SIDEPANE_TYPE_SHORTCUTS,       "ThunarShortcutsPane",                   ("") },
+        { THUNAR_SIDEPANE_TYPE_TREE,            "ThunarTreePane",                        ("") },
+        { THUNAR_SIDEPANE_TYPE_HIDDEN_SHORTCUTS,"void",                                  ("") },
+
+        { 0,                                    NULL,                                    NULL }
+      };
+
+      type = g_enum_register_static ("ThunarSidepaneType", values);
+    }
+
+  return type;
+}
+
+GType thunar_execute_shell_script_get_type (void)
+{
+  static GType type = G_TYPE_INVALID;
+
+  if (G_UNLIKELY (type == G_TYPE_INVALID))
+    {
+      static const GEnumValue values[] =
+      {
+        { THUNAR_EXECUTE_SHELL_SCRIPT_NEVER,  "THUNAR_EXECUTE_SHELL_SCRIPT_NEVER",  ("Never") },
+        { THUNAR_EXECUTE_SHELL_SCRIPT_ALWAYS, "THUNAR_EXECUTE_SHELL_SCRIPT_ALWAYS", ("Always") },
+        { THUNAR_EXECUTE_SHELL_SCRIPT_ASK,    "THUNAR_EXECUTE_SHELL_SCRIPT_ASK",    ("Ask every time") },
+
+        { 0,                                  NULL,                                 NULL }
+      };
+
+      type = g_enum_register_static ("ThunarExecuteShellScript", values);
+    }
+
+  return type;
+}
