@@ -25,6 +25,17 @@
 
 G_BEGIN_DECLS;
 
+
+gboolean transform_enum_value_to_index (GBinding     *binding,
+                                        const GValue *src_value,
+                                        GValue       *dst_value,
+                                        gpointer      user_data);
+
+gboolean transform_index_to_enum_value (GBinding     *binding,
+                                        const GValue *src_value,
+                                        GValue       *dst_value,
+                                        gpointer      user_data);
+
 #define THUNAR_TYPE_RENAMER_MODE (thunar_renamer_mode_get_type ())
 
 /**
@@ -189,12 +200,13 @@ typedef enum
   THUNAR_THUMBNAIL_SIZE_LARGE,
   THUNAR_THUMBNAIL_SIZE_X_LARGE,
   THUNAR_THUMBNAIL_SIZE_XX_LARGE,
-
+  N_THUMBNAIL_SIZES,
   THUNAR_THUMBNAIL_SIZE_DEFAULT = -1
 } ThunarThumbnailSize;
 
-GType       thunar_thumbnail_size_get_type (void)                               G_GNUC_CONST;
-const char* thunar_thumbnail_size_get_nick (ThunarThumbnailSize thumbnail_size) G_GNUC_CONST;
+GType               thunar_thumbnail_size_get_type     (void)                               G_GNUC_CONST;
+const char*         thunar_thumbnail_size_get_nick     (ThunarThumbnailSize thumbnail_size) G_GNUC_CONST;
+ThunarThumbnailSize thunar_icon_size_to_thumbnail_size (ThunarIconSize      icon_size);
 
 
 #define THUNAR_TYPE_PARALLEL_COPY_MODE (thunar_parallel_copy_mode_get_type ())
@@ -204,6 +216,7 @@ const char* thunar_thumbnail_size_get_nick (ThunarThumbnailSize thumbnail_size)
  * @THUNAR_PARALLEL_COPY_MODE_NEVER                   : copies will be done consecutively, one after another.
  * @THUNAR_PARALLEL_COPY_MODE_ONLY_LOCAL              : only do parallel copies when source and destination are local files.
  * @THUNAR_PARALLEL_COPY_MODE_ONLY_LOCAL_SAME_DEVICES : same as only local, but only if source and destination devices are the same.
+ * @THUNAR_PARALLEL_COPY_MODE_ONLY_LOCAL_IDLE_DEVICE  : only for local files. Dont tranfer in parallel if the source or the target already runs a file transfer job (prevent HDD thrashing)
  * @THUNAR_PARALLEL_COPY_MODE_ALWAYS                  : all copies will be started immediately.
  **/
 typedef enum
@@ -211,6 +224,7 @@ typedef enum
   THUNAR_PARALLEL_COPY_MODE_NEVER,
   THUNAR_PARALLEL_COPY_MODE_ONLY_LOCAL,
   THUNAR_PARALLEL_COPY_MODE_ONLY_LOCAL_SAME_DEVICES,
+  THUNAR_PARALLEL_COPY_MODE_ONLY_LOCAL_IDLE_DEVICE,
   THUNAR_PARALLEL_COPY_MODE_ALWAYS
 } ThunarParallelCopyMode;
 
@@ -284,6 +298,7 @@ typedef enum
 
 GType               thunar_zoom_level_get_type            (void)                       G_GNUC_CONST;
 ThunarThumbnailSize thunar_zoom_level_to_thumbnail_size   (ThunarZoomLevel zoom_level) G_GNUC_CONST;
+gint                thunar_zoom_level_to_view_margin      (ThunarZoomLevel zoom_level) G_GNUC_CONST;
 const gchar*        thunar_zoom_level_string_from_value   (ThunarZoomLevel zoom_level);
 gboolean            thunar_zoom_level_value_from_string   (const gchar    *value_string,
                                                            gint           *value);
@@ -480,6 +495,113 @@ typedef enum
 
 GType thunar_image_preview_mode_get_type (void) G_GNUC_CONST;
 
+/**
+ * ThunarFolderItemCount
+ *
+ * Specify when the size column on a folder
+ * should instead show the item count of the folder
+ **/
+
+#define THUNAR_TYPE_FOLDER_ITEM_COUNT (thunar_folder_item_count_get_type ())
+
+/**
+ * ThunarFolderItemCount:
+ * @THUNAR_FOLDER_ITEM_COUNT_NEVER,        : never show number of items as the size of the folder
+ * @THUNAR_FOLDER_ITEM_COUNT_ONLY_LOCAL,   : only show number of items as size of folder for local folders
+ * @THUNAR_FOLDER_ITEM_COUNT_ALWAYS,       : always show the number of items as the size of the folder
+ **/
+typedef enum
+{
+  THUNAR_FOLDER_ITEM_COUNT_NEVER,
+  THUNAR_FOLDER_ITEM_COUNT_ONLY_LOCAL,
+  THUNAR_FOLDER_ITEM_COUNT_ALWAYS,
+} ThunarFolderItemCount;
+
+GType thunar_folder_item_count_get_type (void) G_GNUC_CONST;
+
+/**
+ * ThunarWindowTitleStyle
+ *
+ * Specify whether the window title should display the full directory path instead
+ * of only the directory name and with or without the application name appened.
+ **/
+
+#define THUNAR_TYPE_WINDOW_TITLE_STYLE (thunar_window_title_style_get_type ())
+
+/**
+ * ThunarWindowTitleStyle:
+ * @THUNAR_WINDOW_TITLE_STYLE_FOLDER_NAME_WITH_THUNAR_SUFFIX,    : folder name with the " - thunar" suffix
+ * @THUNAR_WINDOW_TITLE_STYLE_FOLDER_NAME_WITHOUT_THUNAR_SUFFIX, : folder name without the " - thunar" suffix
+ * @THUNAR_WINDOW_TITLE_STYLE_FULL_PATH_WITH_THUNAR_SUFFIX,      : full path with the " - thunar" suffix
+ * @THUNAR_WINDOW_TITLE_STYLE_FULL_PATH_WITHOUT_THUNAR_SUFFIX,   : full path without the " - thunar" suffix
+ **/
+typedef enum
+{
+  THUNAR_WINDOW_TITLE_STYLE_FOLDER_NAME_WITH_THUNAR_SUFFIX,
+  THUNAR_WINDOW_TITLE_STYLE_FOLDER_NAME_WITHOUT_THUNAR_SUFFIX,
+  THUNAR_WINDOW_TITLE_STYLE_FULL_PATH_WITH_THUNAR_SUFFIX,
+  THUNAR_WINDOW_TITLE_STYLE_FULL_PATH_WITHOUT_THUNAR_SUFFIX,
+} ThunarWindowTitleStyle;
+
+GType thunar_window_title_style_get_type (void) G_GNUC_CONST;
+
+/**
+ * ThunarSidepaneType
+ *
+ * Specify which sidepane type to use
+ **/
+#define THUNAR_TYPE_SIDEPANE_TYPE (thunar_sidepane_type_get_type ())
+
+/**
+ * ThunarSidepaneType:
+ * @THUNAR_SIDEPANE_TYPE_SHORTCUTS,        : the shurtcuts sidepane
+ * @THUNAR_SIDEPANE_TYPE_TREE,             : the tree sidepane
+ * @THUNAR_SIDEPANE_TYPE_HIDDEN_SHORTCUTS, : no sidepane. On toggle, recover to shurtcuts sidepane
+ * @THUNAR_SIDEPANE_TYPE_HIDDEN_TREE,      : no sidepane. On toggle, recover to tree sidepane
+ **/
+typedef enum
+{
+  THUNAR_SIDEPANE_TYPE_SHORTCUTS,
+  THUNAR_SIDEPANE_TYPE_TREE,
+  THUNAR_SIDEPANE_TYPE_HIDDEN_SHORTCUTS,
+  THUNAR_SIDEPANE_TYPE_HIDDEN_TREE,
+} ThunarSidepaneType;
+
+GType thunar_sidepane_type_get_type (void) G_GNUC_CONST;
+
+/**
+ * ThunarRenameLauncher:
+ * @THUNAR_RESPONSE_LAUNCHERNAME, : edit launcher name
+ * @THUNAR_RESPONSE_FILENAME,     : edit file name
+ **/
+typedef enum
+{
+    THUNAR_RESPONSE_LAUNCHERNAME,
+    THUNAR_RESPONSE_FILENAME,
+} ThunarResponseType;
+
+/**
+* ThunarExecuteShellScript
+ *
+ * Specify script open action.
+ **/
+#define THUNAR_TYPE_EXECUTE_SHELL_SCRIPT (thunar_execute_shell_script_get_type ())
+
+/**
+ * ThunarExecuteShellScript:
+ * @THUNAR_EXECUTE_SHELL_SCRIPT_NEVER,  : don't execute shell scripts
+ * @THUNAR_EXECUTE_SHELL_SCRIPT_ALWAYS, : always execute shell scripts
+ * @THUNAR_EXECUTE_SHELL_SCRIPT_ASK,    : ask whether to execute shell script or display it
+ **/
+typedef enum
+{
+  THUNAR_EXECUTE_SHELL_SCRIPT_NEVER,
+  THUNAR_EXECUTE_SHELL_SCRIPT_ALWAYS,
+  THUNAR_EXECUTE_SHELL_SCRIPT_ASK,
+} ThunarExecuteShellScript;
+
+GType thunar_execute_shell_script_get_type (void) G_GNUC_CONST;
+
 G_END_DECLS;
 
 #endif /* !__THUNAR_ENUM_TYPES_H__ */
