@@ -29,14 +29,6 @@
 #include <gio/gdesktopappinfo.h>
 #endif
 
-#ifdef HAVE_STDLIB_H
-#include <stdlib.h> /* realpath */
-#endif
-
-#ifndef HAVE_REALPATH
-#define realpath(path, resolved_path) NULL
-#endif
-
 #include <libxfce4util/libxfce4util.h>
 
 #include "thunar/thunar-file.h"
@@ -85,7 +77,10 @@ device_icon_name [] =
 static const gchar     *guess_device_type_from_icon_name           (const gchar *icon_name);
 static       GFileInfo *thunar_g_file_get_content_type_querry_info (GFile       *gfile,
                                                                     GError      *err);
-
+static       void       thunar_g_file_info_set_attribute           (GFileInfo   *info,
+                                                                    ThunarGType  type,
+                                                                    const gchar *setting_name,
+                                                                    const gchar *setting_value);
 
 GFile *
 thunar_g_file_new_for_home (void)
@@ -159,56 +154,38 @@ thunar_g_file_new_for_bookmarks (void)
 
 
 /**
- * thunar_g_file_new_for_symlink_target:
+ * thunar_g_file_resolve_symlink:
  * @file : a #GFile.
  *
- * Returns the symlink target of @file as a GFile.
+ * Returns the resolved symlink target of @file as a new #GFile.
+ * If @file is not a symlink, @file will just be returned
  *
  * Return value: (nullable) (transfer full): A #GFile on success and %NULL on failure.
  **/
 GFile *
-thunar_g_file_new_for_symlink_target (GFile *file)
+thunar_g_file_resolve_symlink (GFile *file)
 {
-  const gchar *target_path;
-  gchar       *file_path;
-  GFile       *file_parent = NULL;
-  GFile       *target_gfile = NULL;
-  GFileInfo   *info = NULL;
-  GError      *error = NULL;
+  gchar       *basename;
+  GFile       *parent = NULL;
+  GFile       *target = NULL;
 
   _thunar_return_val_if_fail (G_IS_FILE (file), NULL);
 
-  /* Intialise the GFileInfo for querying symlink target */
-  info = g_file_query_info (file,
-                            G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET,
-                            G_FILE_QUERY_INFO_NONE,
-                            NULL, &error);
-
-  if (info == NULL)
+  parent = g_file_get_parent (file);
+  if (parent == NULL)
+    return NULL;
+  
+  basename = g_file_get_basename (file);
+  if (basename == NULL)
     {
-      file_path = g_file_get_path (file);
-      g_warning ("Symlink target loading failed for %s: %s",
-                 file_path,
-                 error->message);
-      g_free (file_path);
-      g_error_free (error);
+      g_object_unref (parent);
       return NULL;
     }
 
-  target_path = g_file_info_get_attribute_byte_string (info, G_FILE_ATTRIBUTE_STANDARD_SYMLINK_TARGET);
-  file_parent = g_file_get_parent (file);
-
-  /* if target_path is an absolute path, the target_gfile is created using only the target_path
-  ** else if target_path is relative then it is resolved with respect to the parent of the symlink (@file) */
-  if (G_LIKELY (target_path != NULL && file_parent != NULL))
-    target_gfile = g_file_resolve_relative_path (file_parent, target_path);
-
-  /* free allocated resources */
-  if (G_LIKELY (file_parent != NULL))
-    g_object_unref (file_parent);
-  g_object_unref (info);
-
-  return target_gfile;
+  target = g_file_resolve_relative_path (parent, basename);
+  g_object_unref (parent);
+  g_free (basename);
+  return target;
 }
 
 
@@ -1432,43 +1409,6 @@ thunar_g_file_get_link_path_for_symlink (GFile *file_to_link,
 
 
 
-/**
- * thunar_g_file_get_resolved_path:
- * @file : #GFile for which the path will be resolved
- *
- * Gets the local pathname with resolved symlinks for GFile, if one exists.
- * If non-NULL, this is guaranteed to be an absolute, canonical path.
- *
- * This only will work if all components of the #GFile path actually do exist
- *
- * Return value: (nullable) (transfer full): A #gchar on success and %NULL on failure.
- * The returned string should be freed with g_free() when no longer needed.
- **/
-char*
-thunar_g_file_get_resolved_path (GFile *file)
-{
-  gchar *path;
-  gchar *real_path;
-
-  _thunar_return_val_if_fail (G_IS_FILE (file), NULL);
-
-  path = g_file_get_path (file);
-
-  /* No local path for file found */
-  if (path == NULL)
-    return NULL;
-
-  real_path = realpath (path, NULL);
-
-  if (real_path == NULL)
-    g_warning ("Failed to resolve path: '%s' Error: %s\n", path, strerror (errno));
-
-  g_free (path);
-  return real_path;
-}
-
-
-
 gboolean
 thunar_g_file_is_empty (GFile *file)
 {
@@ -1542,7 +1482,7 @@ thunar_g_file_get_content_type (GFile *gfile)
       is_symlink = g_file_info_get_attribute_boolean (info, G_FILE_ATTRIBUTE_STANDARD_IS_SYMLINK);
       if (is_symlink)
         {
-          GFile *link_target = thunar_g_file_new_for_symlink_target (gfile);
+          GFile *link_target = thunar_g_file_resolve_symlink (gfile);
           g_object_unref (info);
           info = NULL;
           if (link_target != NULL)
@@ -1625,9 +1565,71 @@ thunar_g_file_set_metadata_setting_finish (GObject      *source_object,
 
 
 
+static void
+thunar_g_file_info_set_attribute (GFileInfo   *info,
+                                  ThunarGType  type,
+                                  const gchar *setting_name,
+                                  const gchar *setting_value)
+{
+  switch (type)
+    {
+      case THUNAR_GTYPE_STRING:
+        g_file_info_set_attribute_string (info, setting_name, setting_value);
+        break;
+
+      case THUNAR_GTYPE_STRINGV:
+        gchar **setting_values;
+        setting_values = g_strsplit (setting_value, THUNAR_METADATA_STRING_DELIMETER, 100);
+        g_file_info_set_attribute_stringv (info, setting_name, setting_values);
+        g_strfreev (setting_values);
+        break;
+
+      default:
+        g_warning ("ThunarGType not supported, skipping");
+        break;
+    }
+}
+
+
+
+static gchar*
+thunar_g_file_info_get_attribute (GFileInfo   *info,
+                                  ThunarGType  type,
+                                  const gchar *setting_name)
+{
+  switch (type)
+    {
+      case THUNAR_GTYPE_STRING:
+        return g_strdup (g_file_info_get_attribute_string (info, setting_name));
+
+      case THUNAR_GTYPE_STRINGV:
+        gchar **stringv = g_file_info_get_attribute_stringv (info, setting_name);
+        GList  *string_list = NULL;
+        gchar  *joined_string = NULL;
+
+        if (stringv == NULL)
+          return NULL;
+
+        for (; *stringv != NULL; ++stringv)
+          string_list = g_list_append (string_list, *stringv);
+
+        joined_string = thunar_util_strjoin_list (string_list, THUNAR_METADATA_STRING_DELIMETER);
+        g_list_free (string_list);
+        return joined_string;
+
+      default:
+        g_warning ("ThunarGType not supported, skipping");
+        return NULL;
+    }
+}
+
+
+
 /**
  * thunar_g_file_set_metadata_setting:
  * @file          : a #GFile instance.
+ * @info          : Additional #GFileInfo instance to update
+ * @type          : #ThunarGType of the metadata
  * @setting_name  : the name of the setting to set
  * @setting_value : the value to set
  * @async         : whether g_file_set_attributes_async or g_file_set_attributes_from_info should be used
@@ -1638,6 +1640,7 @@ thunar_g_file_set_metadata_setting_finish (GObject      *source_object,
 void
 thunar_g_file_set_metadata_setting (GFile       *file,
                                     GFileInfo   *info,
+                                    ThunarGType  type,
                                     const gchar *setting_name,
                                     const gchar *setting_value,
                                     gboolean     async)
@@ -1649,16 +1652,17 @@ thunar_g_file_set_metadata_setting (GFile       *file,
   _thunar_return_if_fail (G_IS_FILE_INFO (info));
 
   /* convert the setting name to an attribute name */
-  attr_name = g_strdup_printf ("metadata::thunar-%s", setting_name);
+  attr_name = g_strdup_printf ("metadata::%s", setting_name);
 
   /* set the value in the current info. this call is needed to update the in-memory
    * GFileInfo structure to ensure that the new attribute value is available immediately */
-  g_file_info_set_attribute_string (info, attr_name, setting_value);
+  if (setting_value)
+    thunar_g_file_info_set_attribute (info, type, attr_name, setting_value);
 
   /* send meta data to the daemon. this call is needed to store the new value of
    * the attribute in the file system */
   info_new = g_file_info_new ();
-  g_file_info_set_attribute_string (info_new, attr_name, setting_value);
+  thunar_g_file_info_set_attribute (info_new, type, attr_name, setting_value);
   if (async)
     {
       g_file_set_attributes_async (file, info_new,
@@ -1701,7 +1705,7 @@ thunar_g_file_clear_metadata_setting (GFile       *file,
     return;
 
   /* convert the setting name to an attribute name */
-  attr_name = g_strdup_printf ("metadata::thunar-%s", setting_name);
+  attr_name = g_strdup_printf ("metadata::%s", setting_name);
 
   if (!g_file_info_has_attribute (info, attr_name))
     {
@@ -1720,20 +1724,23 @@ thunar_g_file_clear_metadata_setting (GFile       *file,
 /**
  * thunar_file_get_metadata_setting:
  * @file         : a #GFile instance.
+ * @info         : #GFileInfo instance to extract the setting
+ * @type         : #ThunarGType of the metadata
  * @setting_name : the name of the setting to get
  *
  * Gets the stored value of the metadata setting @setting_name for @file. Returns %NULL
- * if there is no stored setting.
+ * if there is no stored setting. After usage the returned string needs to be released with 'g_free'
  *
- * Return value: (transfer none): the stored value of the setting for @file, or %NULL
+ * Return value: (transfer full): the stored value of the setting for @file, or %NULL
  **/
-const gchar *
+gchar *
 thunar_g_file_get_metadata_setting (GFile       *file,
                                     GFileInfo   *info,
+                                    ThunarGType  type,
                                     const gchar *setting_name)
 {
-  gchar       *attr_name;
-  const gchar *attr_value;
+  gchar *attr_name;
+  gchar *attr_value;
 
   _thunar_return_val_if_fail (G_IS_FILE (file), NULL);
 
@@ -1741,7 +1748,7 @@ thunar_g_file_get_metadata_setting (GFile       *file,
     return NULL;
 
   /* convert the setting name to an attribute name */
-  attr_name = g_strdup_printf ("metadata::thunar-%s", setting_name);
+  attr_name = g_strdup_printf ("metadata::%s", setting_name);
 
   if (!g_file_info_has_attribute (info, attr_name))
     {
@@ -1749,7 +1756,7 @@ thunar_g_file_get_metadata_setting (GFile       *file,
       return NULL;
     }
 
-  attr_value = g_file_info_get_attribute_string (info, attr_name);
+  attr_value = thunar_g_file_info_get_attribute (info, type, attr_name);
   g_free (attr_name);
 
   return attr_value;
