@@ -1415,6 +1415,9 @@ thunar_list_model_file_changed (ThunarFileMonitor *file_monitor,
   gint           i, j;
   GtkTreePath   *path;
   GtkTreeIter    iter;
+  gboolean       found = FALSE;
+  GList          node;
+  GSList        *hidden_link = NULL;
 
   _thunar_return_if_fail (THUNAR_IS_FILE_MONITOR (file_monitor) || file_monitor == NULL);
   _thunar_return_if_fail (THUNAR_IS_LIST_MODEL (store));
@@ -1427,6 +1430,23 @@ thunar_list_model_file_changed (ThunarFileMonitor *file_monitor,
     {
       if (G_UNLIKELY (g_sequence_get (row) == file))
         {
+          found = TRUE;
+
+          /* this file is hidden now & show_hidden is FALSE
+           * so we should remove this file from the view and store
+           * it in the hidden list */
+          if (thunar_file_is_hidden (file) && !store->show_hidden)
+            {
+              hidden_link = g_slist_find (store->hidden, file);
+              if (hidden_link == NULL)
+                store->hidden = g_slist_prepend (store->hidden, g_object_ref (file));
+              node.data = file;
+              node.next = NULL;
+              node.prev = NULL;
+              thunar_list_model_files_removed (store->folder, &node, store);
+              return;
+            }
+
           /* generate the iterator for this row */
           GTK_TREE_ITER_INIT (iter, store->stamp, row);
 
@@ -1481,6 +1501,22 @@ thunar_list_model_file_changed (ThunarFileMonitor *file_monitor,
       row = g_sequence_iter_next (row);
       pos_before++;
     }
+
+  if (found)
+    return;
+
+  /* maybe this file was a hidden file but now it's not
+   * in such a case we need to emit a "files-added" for this file
+   * and remove it from the hidden list */
+  hidden_link = g_slist_find (store->hidden, file);
+  if (hidden_link == NULL || thunar_file_is_hidden (file))
+    return;
+  g_object_unref (hidden_link->data);
+  store->hidden = g_slist_delete_link (store->hidden, hidden_link);
+  node.data = file;
+  node.next = NULL;
+  node.prev = NULL;
+  thunar_list_model_files_added (store->folder, &node, store);
 }
 
 
@@ -1955,7 +1991,7 @@ thunar_list_model_cancel_search_job (ThunarListModel *model)
     {
       exo_job_cancel (EXO_JOB (model->recursive_search_job));
 
-      g_signal_handlers_disconnect_matched (model->recursive_search_job, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, model);
+      g_signal_handlers_disconnect_by_data (model->recursive_search_job, model);
       g_object_unref (model->recursive_search_job);
       model->recursive_search_job = NULL;
     }
@@ -1977,7 +2013,7 @@ thunar_list_model_search_finished (ThunarJob       *job,
 {
   if (store->recursive_search_job)
     {
-      g_signal_handlers_disconnect_matched (store->recursive_search_job, G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, store);
+      g_signal_handlers_disconnect_by_data (store->recursive_search_job, store);
       g_object_unref (store->recursive_search_job);
       store->recursive_search_job = NULL;
     }
@@ -2081,7 +2117,7 @@ thunar_list_model_set_folder (ThunarStandardViewModel *model,
       store->file_was_sorted = FALSE;
 
       /* unregister signals and drop the reference */
-      g_signal_handlers_disconnect_matched (G_OBJECT (store->folder), G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, store);
+      g_signal_handlers_disconnect_by_data (G_OBJECT (store->folder), store);
       g_object_unref (G_OBJECT (store->folder));
     }
 
