@@ -20,12 +20,14 @@
 #ifndef __THUNAR_STANDARD_VIEW_H__
 #define __THUNAR_STANDARD_VIEW_H__
 
-#include <thunar/thunar-clipboard-manager.h>
-#include <thunar/thunar-history.h>
-#include <thunar/thunar-icon-factory.h>
-#include <thunar/thunar-list-model.h>
-#include <thunar/thunar-preferences.h>
-#include <thunar/thunar-view.h>
+#include "thunar/thunar-clipboard-manager.h"
+#include "thunar/thunar-history.h"
+#include "thunar/thunar-icon-factory.h"
+#include "thunar/thunar-list-model.h"
+#include "thunar/thunar-tree-view-model.h"
+#include "thunar/thunar-preferences.h"
+#include "thunar/thunar-view.h"
+#include "thunar/thunar-thumbnailer.h"
 
 G_BEGIN_DECLS;
 
@@ -143,6 +145,12 @@ struct _ThunarStandardViewClass
                                            GtkTreeIter       *iter,
                                            gpointer           data);
 
+  void        (*queue_redraw)           (ThunarStandardView *standard_view);
+
+  void        (*set_model)              (ThunarStandardView *standard_view);
+  void        (*block_selection)        (ThunarStandardView *standard_view);
+  void        (*unblock_selection)      (ThunarStandardView *standard_view);
+
   /* The name of the property in ThunarPreferences, that determines
    * the last (and default) zoom-level for the view classes (i.e. in
    * case of ThunarIconView, this is "last-icon-view-zoom-level").
@@ -156,7 +164,7 @@ struct _ThunarStandardView
 
   ThunarPreferences         *preferences;
 
-  ThunarListModel           *model;
+  ThunarStandardViewModel   *model;
 
   ThunarIconFactory         *icon_factory;
   GtkCellRenderer           *icon_renderer;
@@ -201,6 +209,8 @@ GType               thunar_standard_view_get_saved_view_type   (ThunarStandardVi
 
 XfceGtkActionEntry *thunar_standard_view_get_action_entries (void);
 
+void                thunar_standard_view_queue_redraw          (ThunarStandardView       *standard_view);
+
 
 G_END_DECLS;
 
